========================
Team and repository tags
========================

.. image:: http://governance.openstack.org/badges/watcher-dashboard.svg
    :target: http://governance.openstack.org/reference/tags/index.html

.. Change things from this point on

OpenStack Dashboard plugin for Watcher project
==============================================

The Watcher dashboard is a Horizon plugin that will allow users to realize a
wide range of cloud optimization goals.

Free software: Apache license
Documentation: http://docs.openstack.org/developer/watcher-dashboard
Source: http://git.openstack.org/cgit/openstack/watcher-dashboard
Bugs: http://bugs.launchpad.net/watcher-dashboard
